@@ -2,12 +2,13 @@ from __future__ import annotations
 
 from contextlib import contextmanager
 from threading import Event, Lock, Timer
-from typing import IO, TYPE_CHECKING, Iterator
+from typing import IO, TYPE_CHECKING
 
 from colorama import Fore
 
 if TYPE_CHECKING:
     import sys
+    from collections.abc import Iterator
     from types import TracebackType
 
     if sys.version_info >= (3, 11):  # pragma: no cover (py311+)
@@ -17,10 +18,10 @@ if TYPE_CHECKING:
 
 
 class SyncWrite:
-    """
-    Make sure data collected is synced in-memory and to the target stream on every newline and time period.
+    """Make sure data collected is synced in-memory and to the target stream on every newline and time period.
 
     Used to propagate executed commands output to the standard output/error streams visible to the user.
+
     """
 
     REFRESH_RATE = 0.1
@@ -54,12 +55,12 @@ class SyncWrite:
             self._cancel()
             self._write(len(self._content))
 
-    def handler(self, content: bytes) -> None:
+    def handler(self, content: bytes) -> int:
         """A callback called whenever content is written."""
         with self._content_lock:
             self._content.extend(content)
             if self._target_enabled is False:
-                return
+                return len(content)
             at = content.rfind(b"\n")
             if at != -1:  # pragma: no branch
                 at = len(self._content) - len(content) + at + 1
@@ -69,6 +70,7 @@ class SyncWrite:
                 self._write(at)
         finally:
             self._start()
+        return len(content)
 
     def _start(self) -> None:
         self.timer = Timer(self.REFRESH_RATE, self._trigger_timer)
@@ -99,11 +101,11 @@ class SyncWrite:
         if self._color is None or self._target is None:
             yield
         else:
-            self._target.write(self._color.encode("utf-8"))
+            self._target.write(str(self._color).encode("utf-8"))
             try:
                 yield
             finally:
-                self._target.write(Fore.RESET.encode("utf-8"))
+                self._target.write(str(Fore.RESET).encode("utf-8"))
 
     @property
     def text(self) -> str:
