@@ -72,10 +72,10 @@ class ToxEnv(ABC):
     """A tox environment."""
 
     def __init__(self, create_args: ToxEnvCreateArgs) -> None:
-        """
-        Create a new tox environment.
+        """Create a new tox environment.
 
         :param create_args: tox env create args
+
         """
         self.journal: EnvJournal = create_args.journal  #: handler to the tox reporting system
         self.conf: EnvConfigSet = create_args.conf  #: the config set to use for this environment
@@ -182,6 +182,12 @@ class ToxEnv(ABC):
             desc="environment variables to pass on to the tox environment",
             post_process=pass_env_post_process,
         )
+        self.conf.add_config(
+            keys=["disallow_pass_env"],
+            of_type=list[str],
+            default=[],
+            desc="environment variable patterns to exclude after pass_env glob expansion",
+        )
         self.conf.add_config(
             "parallel_show_output",
             of_type=bool,
@@ -207,17 +213,17 @@ class ToxEnv(ABC):
 
     @property
     def env_dir(self) -> Path:
-        """:return: the tox environments environment folder"""
+        """:returns: the tox environments environment folder"""
         return cast("Path", self.conf["env_dir"])
 
     @property
     def env_tmp_dir(self) -> Path:
-        """:return: the tox environments temp folder"""
+        """:returns: the tox environments temp folder"""
         return cast("Path", self.conf["env_tmp_dir"])
 
     @property
     def env_log_dir(self) -> Path:
-        """:return: the tox environments log folder"""
+        """:returns: the tox environments log folder"""
         return cast("Path", self.conf["env_log_dir"])
 
     @property
@@ -323,9 +329,9 @@ class ToxEnv(ABC):
         raise NotImplementedError
 
     def _setup_env(self) -> None:
-        """
-        1. env dir exists
+        """1. env dir exists
         2. contains a runner with the same type.
+
         """
         conf = {"name": self.conf.name, "type": type(self).__name__}
         with self.cache.compare(conf, ToxEnv.__name__) as (eq, old):
@@ -371,6 +377,9 @@ class ToxEnv(ABC):
             return self._env_vars
 
         result = self._load_pass_env(pass_env)
+        if disallow := self.conf["disallow_pass_env"]:
+            disallow_patterns = [re.compile(fnmatch.translate(e), re.IGNORECASE) for e in disallow]
+            result = {k: v for k, v in result.items() if not any(p.match(k) for p in disallow_patterns)}
         # load/paths_env might trigger a load of the environment variables, set result here, returns current state
         self._env_vars, self._env_vars_pass_env, set_env.changed = result, pass_env.copy(), False
         # set PATH here in case setting and environment variable requires access to the environment variable PATH
