@@ -7,7 +7,7 @@ from abc import ABC
 from functools import partial
 from io import TextIOWrapper
 from pathlib import Path
-from typing import TYPE_CHECKING, Generator, Iterator, List, cast
+from typing import TYPE_CHECKING, cast
 from zipfile import ZipFile
 
 from packaging.requirements import Requirement
@@ -26,6 +26,7 @@ from .pyproject import Pep517VirtualEnvPackager
 from .util import dependencies_with_extras
 
 if TYPE_CHECKING:
+    from collections.abc import Generator, Iterator
     from os import PathLike
 
     from tox.config.sets import EnvConfigSet
@@ -54,7 +55,7 @@ class VenvCmdBuilder(PythonPackageToxEnv, ABC):
         )
         self.conf.add_config(
             keys=["commands"],
-            of_type=List[Command],
+            of_type=list[Command],
             default=[],
             desc="the commands to be called for testing",
         )
@@ -101,20 +102,26 @@ class VenvCmdBuilder(PythonPackageToxEnv, ABC):
         if path.suffix == ".whl":
             wheel_dist = WheelDistribution(path)
             requires: list[str] = wheel_dist.requires or []
-            deps = dependencies_with_extras([Requirement(i) for i in requires], extras, wheel_dist.metadata["Name"])
+            available = set(wheel_dist.metadata.get_all("Provides-Extra") or [])
+            deps = dependencies_with_extras(
+                [Requirement(i) for i in requires], extras, wheel_dist.metadata["Name"], available_extras=available
+            )
             package: Package = WheelPackage(path, deps)
         else:  # must be source distribution
             work_dir = self.env_tmp_dir / "sdist-extract"
             if not work_dir.exists():  # pragma: no branch
                 work_dir.mkdir()
             with tarfile.open(str(path), "r:gz") as tar:
-                tar.extractall(  # noqa: S202
-                    path=str(work_dir),
-                    filter=tarfile.data_filter
-                    if sys.version_info >= (3, 11, 4)
+                kwargs = {}
+                if (
+                    sys.version_info >= (3, 11, 4)
                     or (3, 10, 12) <= sys.version_info < (3, 11)
                     or (3, 9, 17) <= sys.version_info < (3, 10)
-                    else None,
+                ):
+                    kwargs["filter"] = tarfile.data_filter
+                tar.extractall(  # noqa: S202
+                    path=str(work_dir),
+                    **kwargs,
                 )
             # the register run env is guaranteed to be called before this
             assert self._sdist_meta_tox_env is not None  # noqa: S101
@@ -122,7 +129,8 @@ class VenvCmdBuilder(PythonPackageToxEnv, ABC):
                 self._sdist_meta_tox_env.root = next(work_dir.iterdir())  # contains a single egg info folder
                 deps = self._sdist_meta_tox_env.get_package_dependencies(for_env)
                 name = self._sdist_meta_tox_env.get_package_name(for_env)
-            package = SdistPackage(path, dependencies_with_extras(deps, extras, name))
+                available = self._sdist_meta_tox_env.get_package_extras(for_env)
+            package = SdistPackage(path, dependencies_with_extras(deps, extras, name, available_extras=available))
         return [package]
 
     def register_run_env(self, run_env: RunToxEnv) -> Generator[tuple[str, str], PackageToxEnv, None]:
