@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from typing import TYPE_CHECKING, Callable
+from typing import TYPE_CHECKING
 from unittest.mock import ANY
 
 import pytest
@@ -11,6 +11,8 @@ from tox.session.env_select import CliEnv
 from tox.util.ci import is_ci
 
 if TYPE_CHECKING:
+    from collections.abc import Callable
+
     from tox.pytest import CaptureFixture, LogCaptureFixture, MonkeyPatch
     from tox.session.state import State
 
@@ -57,6 +59,7 @@ def test_verbose_no_test() -> None:
         "no_test": True,
         "package_only": False,
         "install_pkg": None,
+        "fail_fast": False,
         "develop": False,
         "hash_seed": ANY,
         "discover": [],
@@ -101,6 +104,7 @@ def test_env_var_exhaustive_parallel_values(
         "force_dep": [],
         "hash_seed": ANY,
         "install_pkg": None,
+        "fail_fast": False,
         "no_provision": False,
         "list_envs": False,
         "list_envs_all": False,
